package com.bytesflow.opencv.media.test;

import com.bytesflow.opencv.media.jni.PQCVMediaProcessor;

import java.io.File;
import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.util.Arrays;
import java.util.concurrent.CountDownLatch;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;


public class OpenCVImageBlurTest {
    private static String sIMAGE_PATH = "/Users/devyk/Downloads/IMG_3067.PNG";
    private static String sSO_PATH = "/Users/devyk/Data/Project/piaoquan/OpenCVSample/output/lib/libpiaoquan_java_opencv.dylib";

    private static boolean TEST_COMPARE = true;
    private static String[] sVIS = {
            "{\"videoPath\":\"http://rescdn.yishihui.com/longvideo/transcode/video/vpc/20220406/18066780OzQx1yXknalwXP43Yb.mp4\",\"clips\":[{\"startTimeMs\":19600,\"endTimeMs\":20600},{\"startTimeMs\":39200,\"endTimeMs\":40200},{\"startTimeMs\":58800,\"endTimeMs\":59800},{\"startTimeMs\":78400,\"endTimeMs\":79400},{\"startTimeMs\":98000,\"endTimeMs\":99000},{\"startTimeMs\":117600,\"endTimeMs\":118600},{\"startTimeMs\":137200,\"endTimeMs\":138200},{\"startTimeMs\":156800,\"endTimeMs\":157800}]}\n",
            "{\"videoPath\":\"http://rescdn.yishihui.com/longvideo/transcode/video/vpc/20220406/18066780OzQx1yXknalwXP43Yb.mp4\",\"clips\":[{\"startTimeMs\":17600,\"endTimeMs\":18600},{\"startTimeMs\":39200,\"endTimeMs\":40200},{\"startTimeMs\":58800,\"endTimeMs\":59800},{\"startTimeMs\":78400,\"endTimeMs\":79400},{\"startTimeMs\":98000,\"endTimeMs\":99000},{\"startTimeMs\":117600,\"endTimeMs\":118600},{\"startTimeMs\":137200,\"endTimeMs\":138200},{\"startTimeMs\":156800,\"endTimeMs\":157800}]}\n",
//            "{\"videoPath\":\"http://rescdn.yishihui.com/longvideo/transcode/video/vpc/20220406/21749322YteIIMdBPThlzRUk95.mp4\",\"clips\":[{\"startTimeMs\":4300,\"endTimeMs\":5300},{\"startTimeMs\":8600,\"endTimeMs\":9600},{\"startTimeMs\":12900,\"endTimeMs\":13900},{\"startTimeMs\":17200,\"endTimeMs\":18200},{\"startTimeMs\":21500,\"endTimeMs\":22500},{\"startTimeMs\":25800,\"endTimeMs\":26800},{\"startTimeMs\":30100,\"endTimeMs\":31100},{\"startTimeMs\":34400,\"endTimeMs\":35400}]}"
    };

    public static void main(String[] args) {
        int loop_counts = sVIS.length;
        int thread_counts = 1;
        if (args.length > 0) {
//            sIMAGE_PATH = args[0];
            sSO_PATH = args[0];
            if (Integer.parseInt(args[1]) > 0)
                loop_counts = Integer.parseInt(args[1]);
            System.out.println("sSO_PATH=" + sSO_PATH + " count=" + loop_counts);
        }
        try {
            PQCVMediaProcessor.initSDK(sSO_PATH);
        } catch (FileNotFoundException e) {
            e.printStackTrace();
            return;
        }


        if (TEST_COMPARE) {
            String src = PQCVMediaProcessor.getVideoSimilarityLists(sVIS[0]);
            String src2 = PQCVMediaProcessor.getVideoSimilarityLists(sVIS[1]);
            float v = PQCVMediaProcessor.getVideoSimilarityValue(src, src2);
            System.out.println("相似值 = " + v);
            return;
        }

        ExecutorService executorService = Executors.newFixedThreadPool(thread_counts);
        for (int j = 0; j < loop_counts; j++) {
            long startTime = System.currentTimeMillis();
            CountDownLatch countDownLatch = new CountDownLatch(thread_counts);
            for (int i = 0; i < thread_counts; i++) {
                executorService.execute(new VisRunable(countDownLatch, sVIS[j]));
            }
            try {
                countDownLatch.await();
                System.out.println("const time = " + (System.currentTimeMillis() - startTime));
                Thread.sleep(1000);
            } catch (InterruptedException e) {
                e.printStackTrace();
            }
        }
        System.out.println("java main exit");
    }

    private static class VisRunable implements Runnable {
        private CountDownLatch countDownLatch;
        private String json;

        public VisRunable(CountDownLatch countDownLatch, String json) {
            this.countDownLatch = countDownLatch;
            this.json = json;
        }

        @Override
        public void run() {
            System.out.println("run index start " + json);
            PQCVMediaProcessor.getVideoSimilarityLists(json);
            System.out.println("run index ok " + json);
            countDownLatch.countDown();
        }
    }

    private static class ImageBlurRunable implements Runnable {

        private CountDownLatch countDownLatch;

        public ImageBlurRunable(CountDownLatch countDownLatch) {
            this.countDownLatch = countDownLatch;
        }

        @Override
        public void run() {
            blurTest();
            countDownLatch.countDown();
        }
    }

    private static void blurTest() {
        try {
            String path = sIMAGE_PATH;
            int ret;
            ret = PQCVMediaProcessor.blurDetectionFromImagePath(path);
            System.out.println("PQCVMediaProcessor path = " + ret);

            File file = new File(path);
            byte[] images = new byte[(int) file.length()];
            FileInputStream fileInputStream = new FileInputStream(file);
            fileInputStream.read(images);
            ret = PQCVMediaProcessor.blurDetectionFromImageBytes(images);
            fileInputStream.close();
            System.out.println("PQCVMediaProcessor bytes = " + ret);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
