//
// Created by 阳坤 on 2022/3/1.
//

#include "utils/video_similarity.h"
#include "utils/count_down_latch.h"
#include "ffmpeg/av_tools.h"

extern "C" {
#include "utils/md5.h"
}


typedef struct VsimBean {
    const char *filepath;
    const char *image_md5;
    std::vector<VideoSimilarityModel *> lists;
    pthread_t id;
} VsimBean;

static void run(const char *filepath, std::vector<VideoSimilarityModel *> *list) {
    long id = video_similarity_detection_init(filepath, nullptr);
    if (id > 0) {
        int ret = video_similarity_detection_start(id, 0, AUDIO,
                                                   list);
//        char md5_str[64] = {0};
//        if (get_file_md5(vsimBean->filepath, md5_str) > 0);
//        vsimBean->image_md5 = strdup(md5_str);
        video_similarity_detection_close(id);
    }
}

static void *run_thread(void *p) {
    auto *vsimBean = (VsimBean *) p;
    run(vsimBean->filepath, &vsimBean->lists);
    return 0;
}


typedef struct Test {
    const char *input;
    CountDownLatch *countDownLatch;
};


static void *run(void *p) {
    auto *test = (Test *) p;
    const char *test_1 = "{\n"
                         "\t\"clips\" : \n"
                         "\t[\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 6900,\n"
                         "\t\t\t\"hashs\" : null,\n"
                         "\t\t\t\"startTimeMs\" : 5900\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 12800,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011101110010011100100011001001110100001101110111\",\n"
                         "\t\t\t\t\t\"pts\" : 11838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011101110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 11879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011101110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 11921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011111110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 11963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011111110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011111110010011100100011001001110100011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011111110010011100100011001001110100011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001111001111110010011100100011001001110100011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001111001111110010011100100011001001110100011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001111001111110010011100100011001001110101011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101011101010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101000001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101000001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101000001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 12796\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 11800\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 18700,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000010100100100000101000000000100001000000000000001000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100100000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0010010000010100000000000010000000100000010000000100000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011010001010100011000000010000001110000010100000110000000100000\",\n"
                         "\t\t\t\t\t\"pts\" : 17963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010100011100000010000011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011000011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011100011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011100011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011100011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011100011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110011110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110011110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110011110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18671\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 17700\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 24600,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011010001110011001000000010100011101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011010001110011001000000010100010101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001110011001000000010100010101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001110011001000000010100010101000001011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001110011001000000010100010101000001011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001110011001000000010100010101000001011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001110011001000000010100010101000001011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100000101000001011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100000101000001011110100011101110111\",\n"
                         "\t\t\t\t\t\"pts\" : 23963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100000101000001011110100011101110111\",\n"
                         "\t\t\t\t\t\"pts\" : 24004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100000101000001011110100011101110111\",\n"
                         "\t\t\t\t\t\"pts\" : 24046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100010101000001011110100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100010101000001011110100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001100000110100010101000001011110100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001100000110100010101000001011000100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001100000110100000101000001011000100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001100011001100000110100000101000001011000100111101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001100011001100000110100000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001110001100011001100000110100000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001110001100011001100000110100000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001110001100011001100000110100000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011110001100011001100000110100000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011110001100011001100000110000000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011110001100011001100000110000001101000001011000101111101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 24588\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 23600\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 30500,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011001000110000000000011000100100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011001000110000000000011000100100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011001000110000000000011000000100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011000000100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011000000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011000000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011000000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0010011100000011000000110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0010011100000011000100110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000100110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000100110000000000011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000100110000000000011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011000000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011000000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30463\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 29500\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 36400,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 35421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 35463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011010001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 35504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011000000010000\",\n"
                         "\t\t\t\t\t\"pts\" : 35546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011000000010000\",\n"
                         "\t\t\t\t\t\"pts\" : 35588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000000000000100100001000000011000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000000000000100100001000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001100000110000001100000011000000100000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001100000110000011100000111000001110000011000001000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001100000111000111100000111000001110000011000001000000\",\n"
                         "\t\t\t\t\t\"pts\" : 36004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100000111000111110000111000001110000111000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 36046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36379\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 35400\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 42300,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001100000011000000111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001100000011000000111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001100000011000000111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001100000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001101000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011100001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011100001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011100001111000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011100001111000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42296\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 41300\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 48200,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100011010001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001010000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48171\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 47200\n"
                         "\t\t}\n"
                         "\t],\n"
                         "\t\"videoPath\" : \"http://rescdn.yishihui.com/longvideo/transcode/video/a0af8fbb58fb4099beb42e592465894c_1529284215127.m3u8\"\n"
                         "}";
    const char *test_2 = "\n"
                         "{\n"
                         "\t\"clips\" : \n"
                         "\t[\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 6900,\n"
                         "\t\t\t\"hashs\" : null,\n"
                         "\t\t\t\"startTimeMs\" : 5900\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 12800,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011101110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 11838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011101110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 11879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011101110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 11921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011111110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 11963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011111110010011100100011001001110100001101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111011111110010011100100011001001110100011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111001111110010011100100011001001110100011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111001111110010011100100011001001110100011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001111001111110010011100100011001001000100011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001111001111110010011100100011001001000101011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101011101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 12254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100001111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100011111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000011100011111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101010001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101000001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101000001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000011111001111110010011100100011001001000101000001010100\",\n"
                         "\t\t\t\t\t\"pts\" : 12754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001111001111110010011100100011001001000101000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 12796\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 11800\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 18700,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000010100100100000101000000010100001000000000000001000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100100000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0010010000010100000000000010000000100000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 17921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011010001010100011000000010000001110000010100000110000000100000\",\n"
                         "\t\t\t\t\t\"pts\" : 17963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010100011100000010000001110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011000011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011100011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011100011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011100011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011100011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011000011110000010100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000011000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001010000011100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000011100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000011100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110000110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110011110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110011110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110011110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0111010001110000001100000111000011110011110100000111000001100000\",\n"
                         "\t\t\t\t\t\"pts\" : 18671\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 17700\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 24600,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011010001010011001100000010100011101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011010001010011001000000010100010101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001110011001000000010100010101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001110011001000000010100010101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000110011001000000010100010101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000110011001000000010100010101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000100011001000000010100010101000000011110100011101100111\",\n"
                         "\t\t\t\t\t\"pts\" : 23879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000100011001000000010100000101000001011110100011101110111\",\n"
                         "\t\t\t\t\t\"pts\" : 23921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000100011001000000010100000101000001011110100011101110111\",\n"
                         "\t\t\t\t\t\"pts\" : 23963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000100011001000000010100000101000001011110100011101110111\",\n"
                         "\t\t\t\t\t\"pts\" : 24004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100010101000001011110100011101110111\",\n"
                         "\t\t\t\t\t\"pts\" : 24046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100010101000001011110100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001000000010100010101000001011110100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001100000010100010101000001011110100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001100000110100010101000001011110100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001100011001100000110100010101000001011000100011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 24254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001100011001100000110100010101000001011000100111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010001100011001100000110100010101000001011000100111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001110001100011001100000110100010101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001110001100011001100000110100000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001110001100011001100000110100000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011110001100011001100000110000000101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011110001100011001100000110000001101000001011000101111101010011\",\n"
                         "\t\t\t\t\t\"pts\" : 24546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011110001100011001100000110000001101000001011000101111101010111\",\n"
                         "\t\t\t\t\t\"pts\" : 24588\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 23600\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 30500,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011001000110000000000011000100100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011001000110000000000011000000100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000000000011000000100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011000000100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011000000100000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011000000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011000000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000000000011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000000000011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 29963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100000011000000110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0010011100000011000000110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0010011100000011000100110000000000011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000100110000000000011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000100110000000000011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000100110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011100000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011000000110000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011000000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0011011100010011000000110000001100011100000111000111100001111000\",\n"
                         "\t\t\t\t\t\"pts\" : 30463\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 29500\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 36400,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 35421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 35463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 35504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001101000011000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 35546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000010000000110100001100000011000000010000\",\n"
                         "\t\t\t\t\t\"pts\" : 35588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000011000000000000100100001100000001000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000001000000000000100000001000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000100000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000000000000000000000000000000000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000000100000110000001100000011000000100000000000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010000001100000110000011100000111000001110000011000000000000\",\n"
                         "\t\t\t\t\t\"pts\" : 35963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001100000111000111100000111000001110000011000001000000\",\n"
                         "\t\t\t\t\t\"pts\" : 36004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001001100000111000111100000111000001110000011000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 36046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100000111000111110000111000001110000111000001010000\",\n"
                         "\t\t\t\t\t\"pts\" : 36088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0000010001011100010111000111110000111000001110000111000001110000\",\n"
                         "\t\t\t\t\t\"pts\" : 36379\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 35400\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 42300,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001100000011000000111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001100000011000000111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000000111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001100011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001111000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011111110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101110111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 41963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42171\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0100010001000011001000000011000001101000011101000111011101110011\",\n"
                         "\t\t\t\t\t\"pts\" : 42296\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 41300\n"
                         "\t\t},\n"
                         "\t\t{\n"
                         "\t\t\t\"endTimeMs\" : 48200,\n"
                         "\t\t\t\"hashs\" : \n"
                         "\t\t\t[\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47213\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47254\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47296\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47338\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47379\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47421\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47463\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47504\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010000010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47546\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47588\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001110000111110001111100001010001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47629\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100011010001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47671\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100011010001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47713\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47754\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001110000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47796\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47838\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47879\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100100\",\n"
                         "\t\t\t\t\t\"pts\" : 47921\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 47963\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100001011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48004\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100001011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48046\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48088\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010010100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48129\n"
                         "\t\t\t\t},\n"
                         "\t\t\t\t{\n"
                         "\t\t\t\t\t\"hashSize\" : 64,\n"
                         "\t\t\t\t\t\"imageHash\" : \"0001010000100000001010000111110001111100011011001010110010100000\",\n"
                         "\t\t\t\t\t\"pts\" : 48171\n"
                         "\t\t\t\t}\n"
                         "\t\t\t],\n"
                         "\t\t\t\"startTimeMs\" : 47200\n"
                         "\t\t}\n"
                         "\t],\n"
                         "\t\"videoPath\" : \"http://rescdn.yishihui.com/longvideo/transcode/video/ab50f30924c342e4b44052e9b22fa5ec_1529501321256.m3u8\"\n"
                         "}";
//    const char *ret_json = get_video_similarity_list(test->input);
    const char *ret_json = get_video_similarity_list(test_1);
    const char *ret_json2 = get_video_similarity_list(test_2);
//    printf("ret_json=%s\n", ret_json);
    printf("相似值为：%f \n", get_video_similarity_value(ret_json, ret_json2));
    test->countDownLatch->countDown();
//    MD5_CTX md5c;
//    MD5Init(&md5c); //初始化
//    unsigned char decrypt[16] = {0};
//    unsigned char decrypt32[32] = {0};
//    size_t read_len = strlen(ret_json);
//    MD5Update(&md5c, (unsigned char *) ret_json, read_len);
//    MD5Final(&md5c, decrypt);
//    char temp[8]={0};
//    strcpy((char *) decrypt32, "");
//    for (int i = 0; i < 16; i++) {
//        sprintf(temp, "%02x", decrypt[i]);
//        strcat((char *) decrypt32, temp);
//    }
//    printf("md5:%s\n", decrypt32);
//
//    char * dejson = "35070e4651614cced5604e93c4a59ff9";

    free(test);
    pthread_exit(NULL);
}

/**
 * 1、判断比对文件的 MD5 是否相等
 *  1.1、如果相等，
 *   1.1.1、判断媒体数据 mate 信息是否一致，如果一致，判断前面 N 关键帧的指纹码
 *  1.2、如果不等
 *   1.2.1、判断媒体数据 mate 信息是否一致, 如果一致，判断前面 N 关键帧的指纹码
 * @param argc
 * @param argv
 * @return
 */
int main(int argc, char *argv[]) {

    const char *arr = "0000010001001111011101110010011100100011001001110100001101110111";
    const char *arr2 = "0000010001001111011101110010011100100011001001110100001101010111";


    int threads = 1;
    const char *inputs[1];
//    inputs[0] =  "{\"videoPath\":\"http://rescdn.yishihui.com/longvideo/transcode/video/b46fd76f98364b3abad8c1297a868f82-1526976612340.m3u8\",\"clips\":[{\"startTimeMs\":3000,\"endTimeMs\":4000},{\"startTimeMs\":6000,\"endTimeMs\":7000},{\"startTimeMs\":9000,\"endTimeMs\":10000},{\"startTimeMs\":12000,\"endTimeMs\":13000},{\"startTimeMs\":15000,\"endTimeMs\":16000},{\"startTimeMs\":18000,\"endTimeMs\":19000},{\"startTimeMs\":21000,\"endTimeMs\":22000},{\"startTimeMs\":24000,\"endTimeMs\":25000}]}";
//    inputs[0] = "{\"videoPath\":\"http://rescdn.yishihui.com/longvideo/transcode/video/6b2efb8d1c6f4095a90b0b276d4b3a291532088309923.m3u8\",\"clips\":[{\"startTimeMs\":500,\"endTimeMs\":1000},{\"startTimeMs\":1000,\"endTimeMs\":1500},{\"startTimeMs\":1500,\"endTimeMs\":2000},{\"startTimeMs\":2000,\"endTimeMs\":2500},{\"startTimeMs\":2500,\"endTimeMs\":3000},{\"startTimeMs\":3000,\"endTimeMs\":3500},{\"startTimeMs\":3500,\"endTimeMs\":4000},{\"startTimeMs\":4000,\"endTimeMs\":4500}]}";
    inputs[0] = "{\"videoPath\":\"http://rescdn.yishihui.com/longvideo/transcode/video/3dbf36e8ec27479581514b8b7b4c8034-1526924772832-safe1594892815.m3u8\",\"clips\":[{\"startTimeMs\":6000,\"endTimeMs\":7000},{\"startTimeMs\":12000,\"endTimeMs\":13000},{\"startTimeMs\":18000,\"endTimeMs\":19000},{\"startTimeMs\":24000,\"endTimeMs\":25000},{\"startTimeMs\":30000,\"endTimeMs\":31000},{\"startTimeMs\":36000,\"endTimeMs\":37000},{\"startTimeMs\":42000,\"endTimeMs\":43000},{\"startTimeMs\":48000,\"endTimeMs\":49000}]}";
//    inputs[3] = "{\"videoPath\":\"http://rescdn.yishihui.com/longvideo/transcode/video/3dbf36e8ec27479581514b8b7b4c8034-1526924772832-safe1594892815.m3u8\",\"clips\":[{\"startTimeMs\":6000,\"endTimeMs\":7000},{\"startTimeMs\":12000,\"endTimeMs\":13000},{\"startTimeMs\":18000,\"endTimeMs\":19000},{\"startTimeMs\":24000,\"endTimeMs\":25000},{\"startTimeMs\":30000,\"endTimeMs\":31000},{\"startTimeMs\":36000,\"endTimeMs\":37000},{\"startTimeMs\":42000,\"endTimeMs\":43000},{\"startTimeMs\":48000,\"endTimeMs\":49000}]}";

//    for (;;) {
    CountDownLatch *countDownLatch = new CountDownLatch(threads);
    for (int i = 0; i < threads; ++i) {
        Test *test = static_cast<Test *>(malloc(sizeof(Test)));
        test->countDownLatch = countDownLatch;
        test->input = inputs[i];
        pthread_t id;
        pthread_create(&id, 0, run, test);
    }
    countDownLatch->await();
    delete countDownLatch;
//    }
    return 1;

//    const char *out_json = "{\n"
//                           "    \"videoPath\": \"\\\"/root/data/xxx.mp4\\\"\",\n"
//                           "    \"clips\": [\n"
//                           "        {\n"
//                           "            \"startTimeMs\": 15000,\n"
//                           "            \"endTimeMs\": 25000,\n"
//                           "            \"fingerprintCode\": [\n"
//                           "                \"\\\"0001000100101010101010\\\"\",\n"
//                           "                \"\\\"0001000100101010101010\\\"\",\n"
//                           "                \"\\\"0001000100101010101010\\\"\",\n"
//                           "                \"\\\"0001000100101010101010\\\"\"\n"
//                           "            ]\n"
//                           "        }\n"
//                           "    ]\n"
//                           "}";

//    auto vs = json2VideoSimilarity(input_json);
//    auto json = videoSimilarity2json(vs);
//
//    int32_t size = 7;
//    const char *filepath[size];
//    //票圈视频iOS客户端上传
//    filepath[0] = "http://rescdn.yishihui.com/longvideo/video/vpc/20220309/17025689Igao51Q0IMBYw8aNKH";
//    //ios 原生上传
//    filepath[1] = "http://rescdn.yishihui.com/longvideo/video/vpc/20220309/17025689VvI5KURrrxzlZ0Kcdv";
//    //iOS h5上传
//    filepath[2] = "http://rescdn.yishihui.com/longvideo/video/vpc/20220309/17025689iBy9WFswYdBNblY9au";
//    //票圈视频安卓客户端上传
//    filepath[3] = "http://rescdn.yishihui.com/longvideo/video/vpc/20220309/17677590exDXG6q75ELejK7aMY";
//    //安卓h5上传
//    filepath[4] = "http://rescdn.yishihui.com/longvideo/video/vpc/20220309/176775906GoWtUCYoVZYDbO1XX";
//    //安卓原生上传
//    filepath[5] = "";
//    //PC 上传
////    filepath[5] = "http://rescdn.yishihui.com/longvideo/video/vpc/20220309/17025689nSyGzifJFr4Apl0zc8";
//    filepath[5] = "http://rescdn.yishihui.com/longvideo/video/vpc/20220310/701939000F0qpyCLetflI3COz";
//    http://rescdn.yishihui.com/longvideo/video/vpc/20220304/17938576TxEh0UJXpzcoYRJuHu
//    //本地 local 上传的视频
//    filepath[6] = "/Users/devyk/Data/Project/sample/github_code/OpenCVSample/temp/19581045gIiFKepxbbplF3XtsG.mp4";

//    run(vs->videoPath,&vs->clips);

//    const char * ret = videoSimilarity2json(vs);

//    const char *local_url = "/Users/devyk/Data/Project/sample/github_code/OpenCVSample/temp/19581045gIiFKepxbbplF3XtsG.mp4";
//    std::vector<VideoSimilarityModel *> local_list;
//    run(local_url, &local_list);
//
//    std::vector<VideoSimilarityModel *> lists[size];
//    int split_count = 10;
////    int total = 3960000;
//    int ii = 1000 * 60 * 6;
//
//    int start = ii;
//    for (int i = 0; i < size; ++i) {
//        auto start_time = getCurrentTimeMills();
//        start = ii;
//        for (int j = 0; j < split_count; ++j) {
//            if (j == 0 || j == split_count - 1) {
//                continue;
//            }
//            auto *item = new VideoSimilarityModel();
//            item->startTimeMs = start;
//            item->endTimeMs = item->startTimeMs + 1000;
//            lists[i].push_back(item);
//            start += ii;
//        }
//        LOGE(">>>filepath=%s \n", filepath[i]);
//        run(filepath[i], &lists[i]);
//        LOGE("<<<filepath=%s cost time=%lld \n", filepath[i], getCurrentTimeMills() - start_time);
//    }
//
//    //本地 local
//    std::vector<VideoSimilarityModel *> local = lists[size - 1];
//    //相似 hash 值
//    int test_vis[6][8] = {0};
//    //所有的 帧
//    int test_vis_total[6][8] = {0};
//    for (int j = 0; j < size - 1; ++j) {
//        for (int g = 0; g < lists[j].size(); ++g) {
//            int *cur_sim = list_sim_compare(local[g]->hashs, lists[j][g]->hashs);
//            int a = cur_sim[0];
//            int b = cur_sim[1];
//            test_vis[j][g] = a;
//            test_vis_total[j][g] = b;
//        }
//    }
//
//
//    for (int i = 0; i < size - 1; ++i) {
//        int a_t = 0, b_t = 0;
//        for (int j = 0; j < 8; ++j) {
//            a_t += test_vis[i][j];
//            b_t += test_vis_total[i][j];
//        }
//        LOGE("%s %s 相似度 = %f \n", filepath[6], filepath[i], a_t * 1.0 / b_t * 1.0);
//    }
//    printf("");

    LOGE("end \n");
    return 0;
}

